tsseg.algorithms.random package
===============================

Baseline: uniformly random change points / state labels. Lower bound for benchmarks.

| **Type:** state detection
| **Supervision:** semi-supervised or unsupervised

**Implementation:** *Origin: new code.*

Submodules
----------

tsseg.algorithms.random.detector module
---------------------------------------

.. automodule:: tsseg.algorithms.random.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.random
   :members:
   :show-inheritance:
   :undoc-members:
